pub struct Signature(/* private fields */);Expand description
Compressed-form Secp256k1 signature.
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn from_bytes(bytes: [u8; 64]) -> Signature
pub fn from_bytes(bytes: [u8; 64]) -> Signature
Construct a Signature directly from its bytes.
This constructor expects the given bytes to be a valid signature. No signing is performed.
Sourcepub fn from_bytes_ref(bytes: &[u8; 64]) -> &Signature
pub fn from_bytes_ref(bytes: &[u8; 64]) -> &Signature
Construct a Signature reference directly from a reference to its bytes.
This constructor expects the given bytes to be a valid signature. No signing is performed.
Sourcepub fn remove_recovery_id(&self) -> [u8; 64]
pub fn remove_recovery_id(&self) -> [u8; 64]
Removes the recovery id from the signature.
Sourcepub fn from_bytes_unchecked(bytes: [u8; 64]) -> Signature
👎Deprecated: Use Signature::from_bytes instead
pub fn from_bytes_unchecked(bytes: [u8; 64]) -> Signature
Use Signature::from_bytes instead
Kept temporarily for backwards compatibility.