pub struct UpgradeTransaction { /* private fields */ }Trait Implementations
Sourceimpl Clone for UpgradeTransaction
impl Clone for UpgradeTransaction
Sourcefn clone(&self) -> UpgradeTransaction
fn clone(&self) -> UpgradeTransaction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpgradeTransaction
impl Debug for UpgradeTransaction
Sourceimpl EstimablePredicates for UpgradeTransaction
impl EstimablePredicates for UpgradeTransaction
Sourcefn estimate_predicates<'life0, 'async_trait>(
&'life0 mut self,
provider: impl DryRunner + 'async_trait,
latest_chain_executor_version: Option<u32>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
UpgradeTransaction: 'async_trait,
fn estimate_predicates<'life0, 'async_trait>(
&'life0 mut self,
provider: impl DryRunner + 'async_trait,
latest_chain_executor_version: Option<u32>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
UpgradeTransaction: 'async_trait,
If a transaction contains predicates, we have to estimate them
before sending the transaction to the node. The estimation will check
all predicates and set the
predicate_gas_used to the actual consumed gas.Sourceimpl From<ChargeableTransaction<UpgradeBody, UpgradeMetadata>> for UpgradeTransaction
impl From<ChargeableTransaction<UpgradeBody, UpgradeMetadata>> for UpgradeTransaction
Sourcefn from(
tx: ChargeableTransaction<UpgradeBody, UpgradeMetadata>,
) -> UpgradeTransaction
fn from( tx: ChargeableTransaction<UpgradeBody, UpgradeMetadata>, ) -> UpgradeTransaction
Converts to this type from the input type.
Sourceimpl From<UpgradeTransaction> for Transaction
impl From<UpgradeTransaction> for Transaction
Sourcefn from(tx: UpgradeTransaction) -> Transaction
fn from(tx: UpgradeTransaction) -> Transaction
Converts to this type from the input type.
Sourceimpl Transaction for UpgradeTransaction
impl Transaction for UpgradeTransaction
fn max_gas(&self, consensus_parameters: &ConsensusParameters) -> u64
fn fee_checked_from_tx( &self, consensus_parameters: &ConsensusParameters, gas_price: u64, ) -> Option<TransactionFee>
Sourcefn check(
&self,
block_height: u32,
consensus_parameters: &ConsensusParameters,
) -> Result<(), Error>
fn check( &self, block_height: u32, consensus_parameters: &ConsensusParameters, ) -> Result<(), Error>
Performs all stateless transaction validity checks. This includes the validity
of fields according to rules in the specification and validity of signatures.
https://github.com/FuelLabs/fuel-specs/blob/master/src/tx-format/transaction.md
fn id(&self, chain_id: ChainId) -> Bytes32
fn maturity(&self) -> Option<u64>
fn expiration(&self) -> Option<u64>
fn owner(&self) -> Option<u64>
fn metered_bytes_size(&self) -> usize
fn inputs(&self) -> &Vec<Input>
fn outputs(&self) -> &Vec<Output>
fn witnesses(&self) -> &Vec<Witness>
fn is_using_predicates(&self) -> bool
Sourcefn precompute(&mut self, chain_id: &ChainId) -> Result<(), Error>
fn precompute(&mut self, chain_id: &ChainId) -> Result<(), Error>
Precompute transaction metadata. The metadata is required for
check_without_signatures validation.fn max_fee(&self) -> Option<u64>
fn size(&self) -> usize
fn witness_limit(&self) -> Option<u64>
fn tip(&self) -> Option<u64>
Sourcefn append_witness(&mut self, witness: Witness) -> Result<usize, Error>
fn append_witness(&mut self, witness: Witness) -> Result<usize, Error>
Append witness and return the corresponding witness index
fn used_coins( &self, base_asset_id: &AssetId, ) -> HashMap<(Address, AssetId), Vec<CoinTypeId>>
fn sign_with<'life0, 'life1, 'async_trait>(
&'life0 mut self,
signer: &'life1 (impl Signer + Send + Sync + 'async_trait),
chain_id: ChainId,
) -> Pin<Box<dyn Future<Output = Result<Signature, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
UpgradeTransaction: 'async_trait,
Sourceimpl TryFrom<Transaction> for UpgradeTransaction
impl TryFrom<Transaction> for UpgradeTransaction
Sourceimpl ValidatablePredicates for UpgradeTransaction
impl ValidatablePredicates for UpgradeTransaction
Sourcefn validate_predicates(
self,
_consensus_parameters: &ConsensusParameters,
_block_height: u32,
) -> Result<(), Error>
fn validate_predicates( self, _consensus_parameters: &ConsensusParameters, _block_height: u32, ) -> Result<(), Error>
If a transaction contains predicates, we can verify that these predicates validate, ie
that they return
trueAuto Trait Implementations
impl Freeze for UpgradeTransaction
impl RefUnwindSafe for UpgradeTransaction
impl Send for UpgradeTransaction
impl Sync for UpgradeTransaction
impl Unpin for UpgradeTransaction
impl UnsafeUnpin for UpgradeTransaction
impl UnwindSafe for UpgradeTransaction