EstimablePredicates

Trait EstimablePredicates 

pub trait EstimablePredicates: Sealed {
    // Required method
    fn estimate_predicates<'life0, 'async_trait>(
        &'life0 mut self,
        provider: impl DryRunner + 'async_trait,
        latest_chain_executor_version: Option<u32>,
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
}

Required Methods

fn estimate_predicates<'life0, 'async_trait>( &'life0 mut self, provider: impl DryRunner + 'async_trait, latest_chain_executor_version: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

If a transaction contains predicates, we have to estimate them before sending the transaction to the node. The estimation will check all predicates and set the predicate_gas_used to the actual consumed gas.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors